summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/machine.cpp
diff options
context:
space:
mode:
author Olivier Galibert <galibert@pobox.com>2017-07-03 22:22:05 +0200
committer Olivier Galibert <galibert@pobox.com>2017-07-03 22:22:22 +0200
commit92ef0f292cd338c01bac2517db779bc82c1bd4db (patch)
tree28c1a123c79583632bee2a923614b553484332df /src/emu/machine.cpp
parent435fee169a3e0bf13ccf10625fc795b26b3f243a (diff)
Initialization ordering fixes (nw)
Diffstat (limited to 'src/emu/machine.cpp')
-rw-r--r--src/emu/machine.cpp8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/emu/machine.cpp b/src/emu/machine.cpp
index 3906671587c..36e107e838d 100644
--- a/src/emu/machine.cpp
+++ b/src/emu/machine.cpp
@@ -233,8 +233,12 @@ void running_machine::start()
// initialize the streams engine before the sound devices start
m_sound = std::make_unique<sound_manager>(*this);
- // first load ROMs, then populate memory, and finally initialize CPUs
- // these operations must proceed in this order
+ // configure the address spaces, load ROMs (which needs
+ // width/endianess of the spaces), then populate memory (which
+ // needs rom bases), and finally initialize CPUs (which needs
+ // complete address spaces). These operations must proceed in this
+ // order
+ m_memory.configure();
m_rom_load = make_unique_clear<rom_load_manager>(*this);
m_memory.initialize();